#
# spec file for package rke
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rke
Version:        1.7.3
Release:        1.3
Summary:        Rancher Kubernetes Engine
License:        Apache-2.0
URL:            https://github.com/rancher/rke
Source:         rke-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22.8

%description
RKE is a fast, versatile Kubernetes installer that you can use to install
Kubernetes on your Linux hosts.
Rancher Kubernetes Engine (RKE) is a CNCF-certified Kubernetes distribution
that runs entirely within Docker containers. It works on bare-metal and
virtualized servers. With RKE, the installation and operation of Kubernetes is
both simplified and easily automated, and it’s entirely independent of the
operating system and platform you’re running.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Wed Feb 19 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.3:
  * What's Changed
  - [release/v1.7] go generate by @rancherbot in #3775
  - [release/v1.7] go generate by @rancherbot in #3783
  * RKE Kubernetes versions
  - v1.28.15-rancher1-1
  - v1.29.13-rancher1-1
  - v1.30.9-rancher1-1
  - v1.31.5-rancher1-1 (default)
* Wed Jan 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.2:
  * What's Changed
  - [release/v1.7] Add ACI-CNI 6.1.1.2 variables by
    @jeffinkottaram in #3765
  - [release/v1.7] go generate by @rancherbot in #3771
  * RKE Kubernetes versions
  - v1.28.15-rancher1-1
  - v1.29.12-rancher1-1
  - v1.30.8-rancher1-1
  - v1.31.4-rancher1-1 (default)
* Tue Dec 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.1:
  * What's Changed
  - [release/v1.7] go generate by @rancherbot in #3748
  - [v1.7] Update GitHub Actions dependencies by @chiukapoor in
    [#3750]
  - [release/v1.7] go generate by @rancherbot in #3751
  - [release/v1.7] Add ACI-CNI 6.0.4.4 variables by
    @jeffinkottaram in #3754
  - [release/v1.7] go generate by @rancherbot in #3756
  * RKE Kubernetes versions
  - v1.28.15-rancher1-1
  - v1.29.11-rancher1-1
  - v1.30.7-rancher1-1
  - v1.31.3-rancher1-1 (default)
* Wed Nov 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.0:
  * What's Changed
  - Bump github.com/opencontainers/runc from 1.1.12 to 1.1.14
  - [v1.31] Bump k8s dependencies to support k8s v1.31
  - [release/v1.7] Add ACI-CNI 6.1.1.1 variables
  - Update action target branch
  * RKE Kubernetes versions
  - v1.28.15-rancher1-1
  - v1.29.10-rancher1-1
  - v1.30.6-rancher1-1
  - v1.31.2-rancher2-1 (default)
* Wed Nov 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.4:
  * What's Changed
  - Introduced 1.28.15, 1.29.10, 1.30.6
  - bump go to v1.22.8
  * RKE Kubernetes versions
  - v1.27.16-rancher1-1
  - v1.28.15-rancher1-1
  - v1.29.10-rancher1-1
  - v1.30.6-rancher1-1 (default)
* Tue Oct 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.3:
  * What's Changed
  - Bump github.com/opencontainers/runc from 1.1.12 to 1.1.14
  - Add ACI-CNI 6.1.1.1 variable
  * RKE Kubernetes versions
  - v1.27.16-rancher1-1
  - v1.28.14-rancher1-1
  - v1.29.9-rancher1-1
  - v1.30.5-rancher1-1 (default)
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.2:
  * [v2.9] Fix panic on context switch by @enrichman in #387
  * [v2.9] Revert error message of #387 by @enrichman in #392
  * [v2.9] Bump dependencies for v2.9.2 by @pmatseykanets in #394
* Tue Aug  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.1:
  * What's Changed
  - Introduced v1.30.3, v1.29.7, v1.28.12 and v1.27.16
  * RKE Kubernetes versions
  - v1.27.16-rancher1-1
  - v1.28.12-rancher1-1
  - v1.29.7-rancher1-1
  - v1.30.3-rancher1-1 (default)
* Tue Jul 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.0:
  * What's Changed
  - Introduced v1.30.2, v1.29.6, v1.28.11 and v1.27.15
    In Kubernetes 1.30 and later, you must use an out-of-tree
    Azure cloud provider. The Azure cloud provider has been
    removed completely, and won't work after an upgrade to
    Kubernetes 1.30
    Weave CNI has been removed starting with Kubernetes 1.30
    (#3623)
    In Kubernetes 1.29, in-tree cloud providers have been
    disabled for all cloud providers. You must disable the
    DisableCloudProviders and
    DisableKubeletCloudCredentialProvider to use the in-tree
    cloud provider. See upstream changes for more details
  - Introduced support for Docker v26.0.x (#3565)
  - Introduced ACI CNI v6.0.4.2 (#3626)
  - Fixed an issue with cluster provisioning and reconciling when
    using extra_env for kube-api (#3597)
  - Fixed an issue with etcd node removal where RKE would would
    try to remove the member indefinitely (#3573)
  - Fixed an issue with k8s >= 1.22 clusters where clusters would
    sporadically fail to scale etcd nodes (#3622)
  * RKE Kubernetes versions
  - v1.27.15-rancher1-1
  - v1.28.11-rancher1-1
  - v1.29.6-rancher1-1
  - v1.30.2-rancher1-1 (default)
* Tue Jul 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.11:
  * What's Changed
  - Introduced v1.28.11 and v1.27.15 (#3620)
  - Introduced ACI CNI v6.0.4.2 (#3625)
  - Fixed an issue with cluster provisioning and reconciling when
    using extra_env for kube-api (#3599)
  - Fixed an issue with k8s >= 1.22 clusters where clusters would
    sporadically fail to scale etcd nodes (#3536)
  * RKE Kubernetes versions
  - v1.25.16-rancher2-3
  - v1.26.15-rancher1-1
  - v1.27.15-rancher1-1
  - v1.28.11-rancher1-1 (default)
* Tue Jun 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.10:
  * RKE Kubernetes versions
  - v1.25.16-rancher2-3
  - v1.26.15-rancher1-1
  - v1.27.14-rancher1-1
  - v1.28.10-rancher1-1 (default)
* Tue May 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.9:
  * What's Changed
  - Bump containerd to v1.6.27. See #3566
  - Fix the issue where not all kube-apiserver containers restart
    after changing the Pod Security Admission Configuration. See
    [#3547]
  * Kubernetes version
  - v1.25.16-rancher2-3
  - v1.26.15-rancher1-1
  - v1.27.13-rancher1-1
  - v1.28.9-rancher1-1 (default)
* Thu Apr 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.8:
  * Kubernetes version
  - v1.25.16-rancher2-3
  - v1.26.15-rancher1-1
  - v1.27.12-rancher1-1
  - v1.28.8-rancher1-1 (default)
* Sat Mar 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.7:
  * What's Changed
  - [v1.28] Bump k8s dependencies to support k8s v1.28 by
    @chiukapoor in #3472
  - [v1.28] go generate by @chiukapoor in #3507
  - [release/v1.5] go generate by @github-actions in #3513
  - fix the bug that delete_local_data is dropped by @jiaqiluo in
    [#3511]
  - [release/v1.5] go generate by @github-actions in #3517
  - [release/v1.5] go generate by @github-actions in #3530
  - Update README with latest versions by @thatmidwesterncoder in
    [#3528]
  - Backport v1.5.6 changes into the 1.5.7 release candidate line
    by @thatmidwesterncoder in #3526
  - [release/v1.5] go generate by @github-actions in #3533
  - Restart kube-apiserver in all CP nodes after changing the Pod
    Security Admission Configuration by @jiaqiluo in #3531
  - Revert "Merge pull request #3531 from
    jiaqiluo/fix-kube-apiserver" by @jiaqiluo in #3537
  - [release/v1.5] go generate by @github-actions in #3541
  - [v1.5] switch KDM branch to release-v2.8 by @jiaqiluo in
    [#3542]
  * Kubernetes version
  - v1.28.7-rancher1-1 (default)
  - v1.27.11-rancher1-1
  - v1.26.14-rancher1-1
  - v1.25.16-rancher2-3
* Sat Mar 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.6:
  * What's Changed
  - Add ACI CNI 6033, 6041 variables #3514
  * Kubernetes version
  - v1.27.11-rancher1-1 (default)
  - v1.26.14-rancher1-1
  - v1.25.16-rancher2-3
* Wed Feb 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.5:
  Note: There is no official release for v1.5.4, the next release
  version available after v1.5.3 is v1.5.5.
  * What's Changed
  - Introduced v1.27.10-rancher1-1 and v1.26.13-rancher1-1
  - Updated containerd to v1.6.27 and runc to v1.1.12 #3495
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.27.10-rancher1-1 (Default)
  - v1.26.13-rancher1-1
  - v1.25.16-rancher2-2
  - Experimental Kubernetes version
  - N/A
* Tue Jan 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.3:
  * What's Changed
  - Add architecture.md by @manuelbuil in #3453
  - Clean/speed up Drone by @superseb in #3417
  - [release/v1.5] Simplify update README workflow by @superseb
    in #3436
  - [v1.5] Added ACI-CNI 6.0.3.2 variables by @akhilesh-oc in
    [#3475]
  - [v1.5] update kdm branch to release-v2.8 by @kinarashah in
    [#3479]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.27.8-rancher2-2 (Default)
  - v1.26.11-rancher2-2
  - v1.25.16-rancher2-2
  - Experimental Kubernetes version
  - N/A
* Thu Jan 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.2:
  * Enhancements
  - Introduced v1.27.8-rancher2-1, v1.26.11-rancher2-1 and
    v1.25.16-rancher2-1
  - Introduced calico and canal v3.26.3 and nginx ingress v1.9.4
    for v1.27.8-rancher2-1, v1.26.11-rancher2-1 and
    v1.25.16-rancher2-1
  * Bug Fixes
  - Added ACI 6.0.3.1 variables
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.27.8-rancher2-1 (Default)
  - v1.26.11-rancher2-1
  - v1.25.16-rancher2-1
  - Experimental Kubernetes version
  - N/A
* Thu Dec 21 2023 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.1:
  * Enhancements
  - Introduced v1.27.8-rancher2-1, v1.26.11-rancher2-1 and
    v1.25.16-rancher2-1
  - Introduced calico and canal v3.26.3 and nginx ingress v1.9.4
    for v1.27.8-rancher2-1, v1.26.11-rancher2-1 and
    v1.25.16-rancher2-1
  * Bug Fixes
  - N/A
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.27.8-rancher2-1 (Default)
  - v1.26.11-rancher2-1
  - v1.25.16-rancher2-1
  - Experimental Kubernetes version
  - N/A
* Sun Dec  3 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.5.0:
  * Enhancements
  - Added support for v1.27.6-rancher1-1.
  - Introduced support for external-aws.
  - In Kubernetes 1.27 and later, you must use an out-of-tree
    AWS cloud provider. See documentation on how to set up
    external-aws.
  - All existing clusters must migrate prior to upgrading to
    v1.27 in order to stay functional. See documentation on how
    to migrate to external-aws on Kubernetes 1.26 and earlier.
  - Note that there is a known issue with external-aws where
    RKE fails to find the node if both hostname-override and
    internal-address are empty. For more information, see #3445
  * Other changes
  - [release/v1.5] Add env var to enable dual-stack in
    cri-dockerd by @superseb in #3370
  - [release/v1.5] Security bumps by @macedogm in #3339
  - Add warning log about weave deprecation by @manuelbuil in
    [#3337]
  - Fix "unknown revision v0.0.0" error caused by the
    k8s.io/kubernetes module by @jiaqiluo in #3387
  - changed etcd restore image to rke-tools for etcd >=3.5.7 by
    @vardhaman22 in #3390
  * Kubernetes Versions
    Each version of RKE has a specific list of supported Kubernetes
    versions. If you want to use a different version than listed
    below, you will need to update Kubernetes using the system
    images option in your cluster.yml.
  - Kubernetes version
  - v1.27.6-rancher1-1 (Default)
  - v1.26.9-rancher1-1
  - v1.25.14-rancher1-1
  - Experimental Kubernetes version
  - N/A
* Thu Nov 16 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.11:
  * Enhancements
    Introduced v1.26.9-rancher1-1, v1.25.14-rancher1-1
  * Bug Fixes
  - N/A
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.26.9-rancher1-1 (Default)
  - v1.25.14-rancher1-1
  - v1.24.17-rancher1-1
  - v1.23.16-rancher2-3
  - Experimental Kubernetes version
  - N/A
* Wed Sep 20 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.10:
  * Enhancements
  - Adds support for Docker v24.0.x
  - Add sandbox image to images to pre-pull by @jakefhyde in
    [#3211]
  - Set the default PodSecurityConfiguration value only if the
    cluster's k8s version is at least 1.23 by @jiaqiluo in #3291
  - Bump google.golang.org/grpc from 1.48.0 to 1.53.0 by
    @dependabot in #3281
  - update README and add troubleshooting doc links by @superseb
    in #3310
  - Replace deprecated io/ioutil by @manuelbuil in #3329
  - [release/v1.4] Security bumps by @macedogm in #3308
  - switch to release-v2.7 for RKE v1.4.10 release by
    @HarrisonWAffel in #3380
  * Bug Fixes
  - Use correct container name in log by @superseb in #3323
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.26.8-rancher1-1 (Default)
  - v1.25.13-rancher1-1
  - v1.24.17-rancher1-1
  - v1.23.16-rancher2-3
  - Experimental Kubernetes version
  - N/A
* Tue Sep 12 2023 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.20
- Update to version 1.4.9:
  * Enhancements
  - Introduced v1.24.17-rancher1-1, v1.25.13-rancher1-1,
    v1.26.8-rancher1-1
  - Added ACI-CNI 6.0.3.1 variables
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.26.8-rancher1-1 (Default)
  - v1.25.13-rancher1-1
  - v1.24.17-rancher1-1
  - v1.23.16-rancher2-3
  - Experimental Kubernetes version
  - N/A
  * New Images in v1.26.8-rancher1-1, v1.25.13-rancher1-1 and
    v1.24.17-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.26.8-rancher1
  - rancher/hyperkube:v1.25.13-rancher1
  - rancher/hyperkube:v1.24.17-rancher1
* Fri Aug  4 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.8:
  * Enhancements
  - Introduced v1.24.16-rancher1-1, v1.25.12-rancher1-1,
    v1.26.7-rancher1-1
  * Bug Fixes
  - Fixed an issue around PodSecurityConfiguration which
    prevented v1.22 clusters to upgrade #3306
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.26.7-rancher1-1 (Default)
  - v1.25.12-rancher1-1
  - v1.24.16-rancher1-1
  - v1.23.16-rancher2-3
  - Experimental Kubernetes version
  - N/A
  * New Images in v1.26.7-rancher1-1, v1.25.12-rancher1-1 and
    v1.24.16-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.26.7-rancher1
  - rancher/hyperkube:v1.25.12-rancher1
  - rancher/hyperkube:v1.24.16-rancher1
* Sat Jul  8 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.7:
  * Enhancements
  - Introduced v1.24.15-rancher1-1, v1.25.11-rancher1-1,
    v1.26.6-rancher1-1
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.26.6-rancher1-1 (Default)
  - v1.25.11-rancher1-1
  - v1.24.15-rancher1-1
  - v1.23.16-rancher2-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.26.6-rancher1-1, v1.25.11-rancher1-1 and
    v1.24.15-rancher1-1
  * Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.26.6-rancher1
  - rancher/hyperkube:v1.25.11-rancher1
  - rancher/hyperkube:v1.24.15-rancher1
  * What's Changed
  - [release/v1.4] Vendor June patches KDM data by @doflamingo721
    in #3269
  - [release/v1.4] Vendor June patches KDM data by @doflamingo721
    in #3276
  - [release/v1.4] update README with latest by @github-actions
    in #3279
  - [release/v1.4] go generate by @github-actions in #3282
  - [release/v1.4] go generate by @github-actions in #3283
  - KDM Out Of Band Update For June 2023 - Rancher v2.7 by
    @HarrisonWAffel in #3286
* Fri Jun 23 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.6:
  * Enhancements
  - Introduced `v1.26.4-rancher2-1`, `v1.25.9-rancher2-2`,
    `v1.24.13-rancher2-2`, and `v1.23.16-rancher2-3`
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the [system images]
    (https://rancher.com/docs/rke/latest/en/config-options/system-images/)
    option in your `cluster.yml`.
  - Kubernetes version
  - v1.26.4-rancher2-1 (Default)
  - v1.25.9-rancher2-2
  - v1.24.13-rancher2-2
  - v1.23.16-rancher2-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.26.4-rancher2-1, v1.25.9-rancher2-2 and
    v1.24.13-rancher2-2
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.26.4-rancher2
  - rancher/hyperkube:v1.25.9-rancher2
  - rancher/hyperkube:v1.24.13-rancher2
* Thu Apr 27 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.5:
  * Enhancements
  - Introduced v1.25.9-rancher2-1, v1.24.13-rancher2-1 and v1.23.16-rancher2-2
  - ACI-CNI version bumped from 5.2.3.5 to 5.2.3.6
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd
    directories for kubelet container could cause
    kubelet/dockershim to send empty portMappings after upgrade.
    The workaround is to bind mount these directories by
    specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either
    address or internal_address does not contain a valid IP
    address (e.g., hostname or FQDN), kube-proxy will fail to
    start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions.  If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
    v1.25.9-rancher2-1 (Default)
    v1.24.13-rancher2-1
    v1.23.16-rancher2-2
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.25.9-rancher2-1 and v1.24.13-rancher2-1
  * Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.25.9-rancher2
  - rancher/hyperkube:v1.24.13-rancher2
* Thu Apr 13 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.4:
  * Enhancements
  - Introduced v1.25.6-rancher4-1.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd
    directories for kubelet container could cause
    kubelet/dockershim to send empty portMappings after upgrade.
    The workaround is to bind mount these directories by
    specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either
    address or internal_address does not contain a valid IP
    address (e.g., hostname or FQDN), kube-proxy will fail to
    start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
    v1.25.6-rancher4-1 (Default)
    v1.24.10-rancher4-1
    v1.23.16-rancher2-1
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.25.6-rancher4-1
  - Updated Hyperkube Image based on k8s versions
    rancher/hyperkube:v1.25.6-rancher4
* Thu Mar  9 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.3:
  * Enhancements
  - Introduced v1.24.10-rancher4-1 and v1.23.16-rancher2-1.
  * Major Bug Fixes
  - Fixed high cpu usage issue for v1.24 clusters #38816
  - Fixed issues around hostname-override for AWS cloud provider:
  - Added hostname-override back to RKE. RKE will continue
    finding the node by matching hostname_override to
    kubernetes.io/hostname label on the node. Fixes node not
    found regression.
  - RKE will now set the hostname-override for kube-proxy to
    the instance metadata hostname only if
    useInstanceMetadataHostname is true. If
    useInstanceMetadataHostname is false, RKE will use
    hostname-override set by users.
  - Refer to RKE PR for more details and rancher/rancher#37634
    (comment) for testing usecases.
  - Fixed upgrade issue from clusters having v1beta1 calico
    custom resource definitions with latest kubernetes versions.
    [#40280]
  - Removed flannel cpu/memory limits with latest kubernetes
    versions #40178
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd
    directories for kubelet container could cause
    kubelet/dockershim to send empty portMappings after upgrade.
    The workaround is to bind mount these directories by
    specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either
    address or internal_address does not contain a valid IP
    address (e.g., hostname or FQDN), kube-proxy will fail to
    start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported
    Kubernetes versions. If you want to use a different version
    than listed below, you will need to update Kubernetes using
    the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.10-rancher4-1 (Default)
  - v1.23.16-rancher2-1
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.10-rancher4-1 and v1.23.16-rancher2-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.10-rancher4
  - rancher/hyperkube:v1.23.16-rancher2
* Tue Jan 24 2023 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.2:
  * Enhancements
  - Introduced v1.24.9-rancher1-1 and v1.23.15-rancher1-1.
  - Introduced calico and canal v3.22.5 for v1.24.9-rancher1-1 and v1.23.15-rancher1-1.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.9-rancher1-1 (Default)
  - v1.23.15-rancher1-1
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.9-rancher1-1 and v1.23.15-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.9-rancher1
  - rancher/hyperkube:v1.23.15-rancher1
* Tue Nov 29 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.4.1:
  * Enhancements
  - Introduced v1.24.8-rancher1-1 and v1.23.14-rancher1-1.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.8-rancher1-1 (Default)
  - v1.23.14-rancher1-1
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.6-rancher1-1 and v1.23.12-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.8-rancher1
  - rancher/hyperkube:v1.23.14-rancher1
* Tue Nov 15 2022 Johannes Kastl <kastl@b1-systems.de>
- update to version 1.4.0:
  * Enhancements
  - Introduced v1.24.6-rancher1-1 and v1.23.12-rancher1-1.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.6-rancher1-1 (Default)
  - v1.23.12-rancher1-1
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.6-rancher1-1 and v1.23.12-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.6-rancher1
  - rancher/hyperkube:v1.23.12-rancher1
* Tue Nov 15 2022 Johannes Kastl <kastl@b1-systems.de>
- update to version 1.3.16:
  * Enhancements
  - Introduced v1.24.6-rancher1-1 and v1.23.12-rancher1-1.
  - Updated v1.22.15 to use new metrics-server v0.5.2.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.6-rancher1-1 (Default)
  - v1.23.12-rancher1-1
  - v1.22.15-rancher1-1
  - v1.21.14-rancher1-1
  - v1.20.15-rancher2-2
  - v1.19.16-rancher2-1
  - v1.18.20-rancher1-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.6-rancher1-1 and v1.23.12-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.6-rancher1
  - rancher/hyperkube:v1.23.12-rancher1
* Sun Sep 25 2022 Johannes Kastl <kastl@b1-systems.de>
- update to version 1.3.15:
  * Enhancements
  - Introduced v1.19.16-rancher2-1 with updated hyperkube image v1.19.16-rancher2. See rancher/38906
  * Bug Fixes
  - Fixed an issue where rke up deletes user addons before redeploying them. See #3042
  - Fixed an issue where rke dies with SIGSEGV on creating an etcd snapshot. See #3028
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.4-rancher1-1 (Default)
  - v1.23.10-rancher1-1
  - v1.22.13-rancher1-1
  - v1.21.14-rancher1-1
  - v1.20.15-rancher2-2
  - v1.19.16-rancher2-1
  - v1.18.20-rancher1-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.19.16-rancher2-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.19.16-rancher2
* Wed Sep  7 2022 Johannes Kastl <kastl@b1-systems.de>
- update to version 1.3.14:
  * Enhancements
  - Introduced v1.24.4-rancher1-1,v1.23.10-rancher1-1, v1.22.13-rancher1-1
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.4-rancher1-1 (Default)
  - v1.23.10-rancher1-1
  - v1.22.13-rancher1-1
  - v1.21.14-rancher1-1
  - v1.20.15-rancher2-2
  - v1.19.16-rancher1-6
  - v1.18.20-rancher1-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.4-rancher1, v1.23.10-rancher1, v1.22.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.4-rancher1
  - rancher/hyperkube:v1.23.10-rancher1
  - rancher/hyperkube:v1.22.13-rancher1
* Wed Sep  7 2022 Johannes Kastl <kastl@b1-systems.de>
- update to version 1.3.13:
  * Enhancements
  - Introduced v1.24.2-rancher1-1,v1.23.8-rancher1-1, v1.22.11-rancher1-1, v1.21.14-rancher1-1 and v1.20.15-rancher2-2
  - cri-dockerd is now enabled by default for v1.24.2-rancher1-1.
  - Added retries for etcd snapshot and other improvements; for more details, see #2952.
  * Bug Fixes
  - Fixed an issue where Docker image pull fails from private registry if cri-dockerd is enabled. See #3002.
  * Known Major Issues
  - Ephemeral /var/lib/dockershim and /var/lib/cri-dockerd directories for kubelet container could cause kubelet/dockershim to send empty portMappings after upgrade. The workaround is to bind mount these directories by specifying extra_binds for kubelet service. See #2993.
  - In clusters where cloud_provider is configured and either address or internal_address does not contain a valid IP address (e.g., hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.24.2-rancher1-1 (Default)
  - v1.23.8-rancher1-1
  - v1.22.11-rancher1-1
  - v1.21.14-rancher1-1
  - v1.20.15-rancher2-2
  - v1.19.16-rancher1-6
  - v1.18.20-rancher1-3
  * Experimental Kubernetes version
  - N/A
  * New Images in v1.24.2-rancher1, v1.23.8-rancher1, v1.22.11-rancher1, v1.21.14-rancher1, v1.20.15-rancher2-2
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.24.2-rancher1
  - rancher/hyperkube:v1.23.8-rancher1
  - rancher/hyperkube:v1.22.11-rancher1
  - rancher/hyperkube:v1.21.14-rancher1
  - rancher/hyperkube:v1.20.15-rancher2
* Wed Jun 22 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.12:
  * Enhancements
  - Introduced v1.23.7-rancher1-1, v1.22.10-rancher1-1 and v1.21.13-rancher1-1
  - Introduced new versions v1.19.16-rancher1-6, v1.20.15-rancher1-4, v1.21.13-rancher1-1, v1.22.10-rancher1-1 and v1.23.7-rancher1-1 to use nginx-1.2.1-rancher1 based off of upstream nginx ingress v1.2.1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.23.7-rancher1-1 (Default)
  - v1.22.10-rancher1-1
  - v1.21.13-rancher1-1
  - v1.20.15-rancher1-4
  - v1.19.16-rancher1-6
  - v1.18.20-rancher1-3
  * New Images in v1.23.7-rancher1, v1.22.10-rancher1, v1.21.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.23.6-rancher1
  - rancher/hyperkube:v1.22.10-rancher1
  - rancher/hyperkube:v1.21.13-rancher1
* Fri May 13 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.11:
  * Enhancements
  - Kubernetes v1.23 is no longer experimental; it is now supported and the default version.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.23.6-rancher1-1 (Default)
  - v1.22.9-rancher1-1
  - v1.21.12-rancher1-1
  - v1.20.15-rancher1-3
  - v1.19.16-rancher1-5
  - v1.18.20-rancher1-3
  * New Images in v1.23.6-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.23.6-rancher1
* Fri Apr 29 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to 1.3.10:
  * Enhancements
  - Introduced new Kubernetes versions v1.21.12-rancher1-1, v1.22.9-rancher1-1 and v1.23.6-rancher1-1 which use etcd v3.5.3. Etcd v3.5.3 fixes inconsistent revisions and data occurs in v3.5.0-v3.5.2.
  - Introduced new versions v1.19.16-rancher1-5, v1.20.15-rancher1-3, v1.21.12-rancher1-1, v1.22.9-rancher1-1 and v1.23.6-rancher1-1 to use nginx-1.2.0-rancher1 based off of upstream nginx ingress v1.2.0 for CVE-2021-25745.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.22.9-rancher1-1
  - v1.21.12-rancher1-1
  - v1.20.15-rancher1-3
  - v1.19.16-rancher1-5
  - v1.18.20-rancher1-3
  - Experimental Kubernetes version
  - v1.23.6-rancher1-1
  * New Images in v1.23.6-rancher1, v1.22.9-rancher1, and v1.21.12-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.23.6-rancher1
  - rancher/hyperkube:v1.22.9-rancher1
  - rancher/hyperkube:v1.21.12-rancher1
* Tue Apr  5 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to 1.3.9:
  * BUGFIX:
    A data-corruption issue is reported in etcd 3.5.0, 3.5.1 and 3.5.2 per upstream etcd advisory. The upstream issue has not yet been resolved and no fix is available.
    All 1.22 and 1.23 releases of RKE embed etcd v3.5.x. For this reason, we recommend that users avoid deploying new production Kubernetes clusters using these releases until the issue is fixed upstream and we publish a release that includes that fix.
    Please note that RKE v1.3.8+ creates clusters with v1.22.x by default so we recommend setting kubernetes_version: in cluster.yml to other available Kubernetes versions.
    For existing clusters created with these versions, upstream recommends:
    Enable data corruption check with --experimental-initial-corrupt-check flag. The flag is the only reliable automated way of detecting an inconsistency. This mode has seen significant usage in production and is going to be promoted as default in etcd v3.6.
    Per upstream recommendation as mentioned above, please update your existing clusters to the following new versions introduced with RKE v1.3.9: v1.22.7-rancher1-2 and v1.23.4-rancher1-2. They have the etcd arg experimental-initial-corrupt-check set to true.
    Note this may not always work etcd-io/etcd#13766 (comment) and we suggest not deploying new clusters on production with these versions.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.22.7-rancher1-2
  - v1.21.10-rancher1-1
  - v1.20.15-rancher1-2
  - v1.19.16-rancher1-4
  - v1.18.20-rancher1-3
  - Experimental Kubernetes version
  - v1.23.4-rancher1-2
  * New Images in v1.23.4-rancher1-2, v1.22.7-rancher1-2, and v1.21.10-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.23.4-rancher1
  - rancher/hyperkube:v1.22.7-rancher1
  - rancher/hyperkube:v1.21.10-rancher1
* Sat Mar 26 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.17
* Fri Mar 25 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to 1.3.8:
  * Enhancements
  - Kubernetes v1.22 is no longer experimental and is now supported. Kubernetes v1.23 is experimental.
  * Major Bug Fixes
  - CoreDNS Autoscaler now has a readiness and liveness check. See #24939.
  - Fixed a regression such that options passed in cluster configuration for nginx configuration don't get passed to the new nginx ingress controller configmap. This is fixed with Kubernetes versions 1.19.16-rancher1-4, 1.20.15-rancher1-2, 1.21.9-rancher1-2. See #36851 for more information.
  - Fixed an issue where rotateEncryptionKey resulted into a panic when creating cluster. See #36333.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.22.7-rancher1-1
  - v1.21.10-rancher1-1
  - v1.20.15-rancher1-2
  - v1.19.16-rancher1-4
  - v1.18.20-rancher1-3
  - Experimental Kubernetes version
  - v1.23.4-rancher1-1
  * New Images in v1.23.4-rancher1, v1.22.7-rancher1, and v1.21.10-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.23.4-rancher1
  - rancher/hyperkube:v1.22.7-rancher1
  - rancher/hyperkube:v1.21.10-rancher1
* Wed Feb  9 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.7:
  * Security Enhancements
  - Updated NGINX Ingress Controller image to v1.1.0 to address critical CVEs. See #36136.
  * Major Bug Fixes
  - Fixed a regression in nginx ingress template where tcp-services-configmap and udp-services-configmap weren't applied on upgrade from nginx-ingress-v0.30.0 to >=controller-v0.31.0. See #35943.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. See #1725.
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.21.9-rancher1-1
  - v1.20.15-rancher1-1
  - v1.19.16-rancher1-3
  - v1.18.20-rancher1-3
  - Experimental Kubernetes version
  - v1.22.6-rancher1-1
  * New Images in v1.22.6-rancher1, v1.21.9-rancher1, and v1.20.15-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.22.6-rancher1
  - rancher/hyperkube:v1.21.9-rancher1
  - rancher/hyperkube:v1.20.15-rancher1
* Wed Jan 26 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.6:
  * Enhancements
  - Introduced new Kubernetes images v1.22.5-rancher2, and v1.21.8-rancher2 to use new hyperkube base with updated iptables > 1.8.5 rancher/rancher#35709
  * Fixes
  - Added logic to delete hostname-override in kubelet for aws cloud provider #2803
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - Kubernetes version
  - v1.21.8-rancher2-1
  - v1.20.14-rancher2-1
  - v1.19.16-rancher1-3
  - v1.18.20-rancher1-3
  - Experimental Kubernetes version
  - v1.22.5-rancher2-1
  * New Images in v1.22.5-rancher1 and v1.21.8-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.22.5-rancher2
  - rancher/hyperkube:v1.21.8-rancher2
* Wed Jan 26 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.5:
  changelog not yet available on the GitHub Release page
  https://github.com/rancher/rke/releases/tag/v1.3.5
* Wed Jan 26 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.4:
  * Enhancements
  - Introduced new Kubernetes images v1.22.5-rancher1, v1.21.8-rancher1 and v1.20.14-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.22.5-rancher1-1
  - v1.21.8-rancher1-1
  - v1.20.14-rancher1-1
  - v1.19.16-rancher1-2
  - v1.18.20-rancher1-3
  * New Images in v1.22.5-rancher1, v1.21.8-rancher1 and v1.20.14-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.22.5-rancher1
  - rancher/hyperkube:v1.21.8-rancher1
  - rancher/hyperkube:v1.20.14-rancher1
* Tue Jan  4 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.3:
  * Enhancements
  - Introduced new Kubernetes images v1.22.4-rancher1, v1.21.7-rancher1 and v1.20.13-rancher1.
  * Fixes
  - Fixed an issue where custom encryption config didn't work in cluster.yml. [#2701]
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.22.4-rancher1-1
  - v1.21.7-rancher1-1
  - v1.20.13-rancher1-1
  - v1.19.16-rancher1-2
  - v1.18.20-rancher1-3
  * New Images in v1.22.4-rancher1, v1.21.7-rancher1 and v1.20.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.22.4-rancher1
  - rancher/hyperkube:v1.21.7-rancher1
  - rancher/hyperkube:v1.20.13-rancher1
* Tue Jan  4 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.2:
  * Enhancements
  - Introduced new Kubernetes images v1.21.6-rancher1, v1.20.12-rancher1 and v1.19.16-rancher1.
  - Introduced new nginx-ingress image nginx-0.49.3-rancher1 to address CVE-2021-25742 for v1.21.6-rancher1, v1.20.12-rancher1 and v1.19.16-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.21.6-rancher1-1
  - v1.20.12-rancher1-1
  - v1.19.16-rancher1-1
  - v1.18.20-rancher1-2
  * New Images in v1.21.6-rancher1, v1.20.12-rancher1, v1.19.16-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.21.6-rancher1
  - rancher/hyperkube:v1.20.12-rancher1
  - rancher/hyperkube:v1.19.16-rancher1
* Tue Jan  4 2022 Johannes Kastl <kastl@b1-systems.de>
- Update to version 1.3.1:
  * Enhancements
  - Introduced new Kubernetes images v1.21.5-rancher1, v1.20.11-rancher1, and v1.19.15-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.21.5-rancher1-1
  - v1.20.11-rancher1-2
  - v1.19.15-rancher1-2
  - v1.18.20-rancher1-2
  * New Images in v1.20.9-rancher1, v1.19.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.21.5-rancher1
  - rancher/hyperkube:v1.20.11-rancher1
  - rancher/hyperkube:v1.19.15-rancher1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 1.3.0:
  * Enhancements
  - Introduced support for Kubernetes v1.21.
  - Introduced option to enable cri-dockerd for Kubernetes v1.21.
  - Introduced support to enable IPv6DualStack for Kubernetes v1.21. #1902
  - Introduced support for ECR plugin #28693
  * Major Bug Fixes since v1.2.11
  - Fixed an issue where etcd snapshot-restore fails with encryption and custom certs #2559
  - Fixed an issue for v1.21 clusters where Flannel pods do not come active on SELinux enabled nodes #2620
  - Fixed an issue where etcd-snapshot save without local state file waits for state file to get copied #2492
  - Fixed an issue where proxy env vars weren't unset correctly for bastion host #2525
  - Fixed an issue for vsphere clusters where addon jobs don't complete before timeout #2535
  - Fixed an issue where etcd fails to find hostname certs with uppercase cert names. #2485
  - Fixed an issue where cert generate-csr does not reflect changes to nodes #2571
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.21.4-rancher1-1
  - v1.20.10-rancher1-2
  - v1.19.14-rancher1-2
  - v1.18.20-rancher1-2
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 1.2.15:
  * Enhancements
  - Introduced new Kubernetes images v1.20.13-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.13-rancher1-1
  - v1.19.16-rancher1-1
  - v1.18.20-rancher1-2
  - v1.17.17-rancher2-3
  * New Images in v1.20.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.13-rancher1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 1.2.14:
  * Enhancements
  - Introduced new Kubernetes images v1.20.12-rancher1 and v1.19.16-rancher1.
  - Introduced new nginx-ingress image nginx-0.49.3-rancher1 to address CVE-2021-25742 for v1.20.12-rancher1 and v1.19.16-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.12-rancher1-1
  - v1.19.16-rancher1-1
  - v1.18.20-rancher1-2
  - v1.17.17-rancher2-3
  * New Images in v1.20.12-rancher1, v1.19.16-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.12-rancher1
  - rancher/hyperkube:v1.19.16-rancher1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 1.2.13:
  * Enhancements
  - Introduced new Kubernetes images v1.20.11-rancher1, and v1.19.15-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.11-rancher1-1
  - v1.19.15-rancher1-1
  - v1.18.20-rancher1-2
  - v1.17.17-rancher2-3
  * New Images in v1.20.9-rancher1, v1.19.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.11-rancher1
  - rancher/hyperkube:v1.19.15-rancher1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 1.2.12:
  * Update kdm data
  * Updated nginx ingress addon to remove admission batch jobs if they exist
* Thu Jul 29 2021 kastl@b1-systems.de
- Update to version 1.2.11:
  * Bugfixes:
  - changed the default kubernetes version to v1.20.9-rancher1-1, this was incorrectly set to an older version v1.20.8-rancher1-1
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.9-rancher1-1
  - v1.19.13-rancher1-1
  - v1.18.20-rancher1-2
  - v1.17.17-rancher2-3
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.9-rancher1
  - rancher/hyperkube:v1.19.13-rancher1
  - rancher/hyperkube:v1.18.20-rancher1
* Wed Jul 28 2021 alexandre.vicenzi@suse.com
- Update to version 1.2.10:
  * Enhancements
  - Introduced new Kubernetes images v1.20.9-rancher1, and v1.19.13-rancher1.
  * Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  * Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.9-rancher1
  - v1.19.13-rancher1
  - v1.18.20-rancher1-2
  - v1.17.17-rancher2-3
  * New Images in v1.20.9-rancher1, v1.19.13-rancher1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.9-rancher1
  - rancher/hyperkube:v1.19.13-rancher1
  - rancher/hyperkube:v1.18.20-rancher1
* Sat May 15 2021 kastl@b1-systems.de
- Update to version 1.2.8:
  Enhancements
  - Introduced new Kubernetes images v1.20.6-rancher1-1, v1.19.10-rancher1-1, v1.18.18-rancher1-2 and v1.17.17-rancher2-3
  - Kubeconfig and state files have file permissions set to 0600
  - The S3 Access Key and Secret Key are passed as environment variables to the etcd-rolling-snapshots container
  Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.6-rancher1-1
  - v1.19.10-rancher1-1
  - v1.18.18-rancher1-2
  - v1.17.17-rancher2-3
  New Images in v1.20.6-rancher1-1, v1.19.10-rancher1-1, v1.18.18-rancher1-2 and v1.17.17-rancher2-3
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.6-rancher1
  - rancher/hyperkube:v1.19.10-rancher1
  - rancher/hyperkube:v1.18.18-rancher1
  - rancher/hyperkube:v1.17.17-rancher2
* Thu Apr  1 2021 kastl@b1-systems.de
- Update to version 1.2.7:
  Enhancements
  - Introduced new Kubernetes images v1.20.5-rancher1-1, v1.19.9-rancher1-1 andv1.18.17-rancher1-1.
  Known Major Issues
  - In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  Kubernetes Versions
  - Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  - v1.20.5-rancher1-1
  - v1.19.9-rancher1-1
  - v1.18.17-rancher1-1
  - v1.17.17-rancher2-1
  New Images in v1.20.5-rancher1-1, v1.19.9-rancher1-1 and v1.18.16-rancher1-1
  - Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.5-rancher1
  - rancher/hyperkube:v1.19.9-rancher1
  - rancher/hyperkube:v1.18.17-rancher1
* Fri Mar 12 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refactor packaging without golang-packaging macros designed for GOPATH
  * Upstream project has converted to go modules
  * go modules no longer needs %%goprep macro to move sources under GOPATH
  * Drop BuildRequires: fdupes no longer needed to check %%goprep source moves
* Sun Mar  7 2021 kastl@b1-systems.de
- Update to version 1.2.6:
  * generate
  * Update kdm data
  * Fix JSON tags camel case for ACI network provider
  * Go generate
  * Go generate
  * Go generate
  * Go generate
  * Add priority class name to addons
  * Go generate
  * Add auditlog checksum to trigger restart on update
  * Go generate for adding k8s 1.20
  * generate
  * kdm bump for windows 2004 and 20h2
  * Improve logging when using custom certs
  * Warn when snapshot name contains file extension
  * update kdm
  * Mark all default addons as critical
  * Add util command
  * Added etcd snapshot timeout parameter
  * Exclude Cisco ACI image from mirror
  * Update to k8s v1.20
  * DeleteLocalData is now DeleteEmptyDirData in k8s v1.20
  * go generate
  * controlplane typo
  * go generate
  * init metadata only if metadataInitialized is false
  * reduce rewrite workers, add additional logging around secrets retrieval
  * go generate
  * key rotation as part of ClusterUp, more robust secrets rewrite, improved logging
  * vendor kdm
  * go generate
  * Set default http backend to be optional
  * kdm changes for 2.5.4rc2
  * go generate
  * generated data/types
  * Add tolerations option to addons
  * Add retry to TCP port check
  * wait for kdm metadata to be initialized
  * Remove latest from rke releases URL in warning
  * Take in ACI template KDM merge
  * go generate changes
  * Introduce ACI CNI network provider
  * vendor update kdm
  * Update KDM - add v.16.15-rancher1-2
  * vendor update kdm
  * go generate
  * vendor update kdm
  * generate
  * set default ingress network mode for both rancher and rke
  * generated data
  * updated NodeUpgradeStrategy.Drain to use pointer
  * Updated cluster/addons.go to allow it to parse and send new http_port and https_ports to the ingress template
  * Updated Addon Timeout to 45s
  * update kdm
  * Check etcd cluster health after member delete
  * Add upgrade tests to integration
  * Vendor KDM
  * vendor kdm v1.15.12-rancher2-6 / rke-tools v0.1.65
  * Bump data
  * Don't advertise etcd port 4001 in v3.4.13 and up
  * Check rollout status in integration test
  * go generate using latest dev-v2.5 data
  * Vendor KDM for Flannel v0.13.0-rancher1
  * Revert "set ignoreDaemonsets field as nonnullable"
  * Vendor kdm v1.17.12, v1.18.9, v1.19.2 + 1.16.15 ingress
  * set ignoreDaemonsets field as nonnullable
  * Fix panic when IgnoreDockerVersion is nil
  * Create loglink for etcd-rolling-snapshots
  * Use node label when cloudprovider is configured
  * hosts: mapping Flatcar from the docker host info
  * update RKEVersionDev
  * update kdm to hide 1.15 for new clusters
  * Vendor KDM which has 1.19
  * Vendor kdm v1.18.8, v1.17.11, v1.16.14, v1.16.15
  * Revert "Vendor kdm v1.18.8, v1.17.11, v1.16.14, v1.16.15"
  * Vendor kdm v1.18.8, v1.17.11, v1.16.14, v1.16.15
  * Update dind Docker to 19.03
  * Remove statefile for dind remove
  * Add CanalControllers to the systemImagesDefaultsMap
  * Add CanalControllers to support Canal v3.14.0+
  * generate
  * cluster/plan: don't relabel /lib/modules by default
  * Get base for copied statefile for snapshot
  * types
  * added windows path cleaner
  * updates for prefix path
  * add win_ params for prefix path, env, args and binds
  * Always build all binaries in Drone
  * pin golang.org/x/sys due to breaking API change
  * vendor update
  * Change file copy method for state file
  * Update to Go 1.14.7
  * vendor update kdm
  * Update base images to Ubuntu 20.04
  * Add restore flag to use local state
  * vendor update kdm
  * update rke version
  * vendor update kdm
  * go fmt
  * add comment
  * add rke2 data field
  * Able to include and extract state file in snapshot
  * Update vendor
  * Remove references to rancher/types
  * Add generated code
  * Move rke types from rancher/types to ./types
  * Check ignoreDaemonsets for nil to avoid panic
  * Check drainInput for nil to avoid panic
  * vendor types
  * Revert kubelet fix as Docker 19.03.9 has fix
  * Actually remove the resources in delete addonjob
  * Updated api bool fields with default=true to *bool. Go files
  * Updated api bool fields with default=true to *bool. Go modules and vendor files
  * Update kdm to latest dev-v2.5
  * Update kdm to latest dev-v2.5
  * undo reverting RKEVersionDev bump
  * Revert "Add support for k8s 1.18"
  * updated data.json
  * updated data.json
  * generated data for ingress template fix
  * generated data
  * update data.json
  * Add test case for GetKubeletDockerConfig
  * Use standard base64 encoding for Docker auth
  * Dont relabel volumes on upstream Docker & SELinux
  * updated data.json
  * Add support for k8s 1.18
  * Remove user addons when not present
  * update bindata/data.json
  * update bindata/data.json
  * update bindata/data.json
  * update bindata/data.json
  * Change data.json source to dev-v2.5
  * Refactor to new client-go API in k8s 1.18
  * Update vendor
  * Fix restoring backups when custom certs are used
* Sun Mar  7 2021 Johannes Kastl <kastl@b1-systems.de>
- update to v1.2.6
  Enhancements
  - Introduced new Kubernetes images v1.20.4-rancher1-1, v1.19.8-rancher1-1, v1.18.16-rancher1-1 and 1.17.17-rancher2-1
  - Made priority class name configurable #30047
  - Added an auditlog configuration checksum to trigger kube-apiserver restart when auditlog configuration changes #2440
  - Added a warning when a snapshot name has a zip extension #2435
  Known Major Issues
  In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  Kubernetes Versions
  Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  Kubernetes version
  - v1.20.4-rancher1-1
  - v1.19.8-rancher1-1
  - v1.18.16-rancher1-1
  - v1.17.17-rancher2-1
  New Images in v1.19.8-rancher1-1, v1.18.16-rancher1-1, and v1.17.17-rancher2-1
    Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.20.4-rancher1
  - rancher/hyperkube:v1.19.8-rancher1
  - rancher/hyperkube:v1.18.16-rancher1
  - rancher/hyperkube:v1.17.17-rancher2
* Sat Mar  6 2021 Johannes Kastl <kastl@b1-systems.de>
- first version of this package, based on v1.1.15
  Enhancements
  - Introduced new Kubernetes images v1.18.16-rancher1-1 and 1.17.17-rancher2-1
  - Added support for Docker 20.10.x [#31223]
  Known Major Issues
  In clusters where cloud_provider is configured, and either address or internal_address does not contain a valid IP address (e.g. hostname or FQDN), kube-proxy will fail to start. [#1725]
  Kubernetes Versions
  Each version of RKE has a specific list of supported Kubernetes versions. If you want to use a different version than listed below, you will need to update Kubernetes using the system images option in your cluster.yml.
  Kubernetes version
  - v1.18.16-rancher1-1
  - v1.17.17-rancher2-1
  New Images in v1.18.16-rancher1-1 and v1.17.17-rancher2-1
    Updated Hyperkube Image based on k8s versions
  - rancher/hyperkube:v1.18.16-rancher1
  - rancher/hyperkube:v1.17.17-rancher2
